import React, { useState } from "react"
import FileBrowser from "./components/FileBrowser"
import { BrowserRouter as Router, Switch, Route, Redirect } from "react-router-dom"
import NotFound from "./components/NotFound"
import Login from "./components/Login"
import { useIsAuthQuery } from "./generated/graphql"
  
const App: React.FC = () => {
	const {data: isAuth, loading } = useIsAuthQuery()
	const [loginSuccessful,setLoginSuccessful] = useState(false)

	const loginRoutes = ()=>{
		if (loginSuccessful || isAuth?.authorized){
			// Routes available when logged in
			return <>
				<Route path="/f/" component={FileBrowser}/>
				<Redirect from="/" exact to="/f/" />
			</>
		}else{
			// Routes available when NOT logged in
			return <>
				<Route path="/login" exact >
					<Login onLogin={()=>{
						setLoginSuccessful(true)
					}} />
				</Route>
				<Redirect from="*" to="/login" />
			</>
		}
	}

	return (
		<div className="dark:text-gray-300">
			{
				!loading && 
				<Router>
					<Switch>
						{loginRoutes()}
						<Route path="*" component={NotFound} />
					</Switch>
				</Router>
			}
		</div>
	)
}

export default App
